@@ -2,53 +2,53 @@
    file accompanying popt source distributions, available from 
    ftp://ftp.redhat.com/pub/code/popt */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-
-/* AIX requires this to be the first thing in the file.  */
-#ifndef __GNUC__
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else
-#  ifdef _AIX
-#pragma alloca
-#  else
-#   ifndef alloca /* predefined by HP cc +Olibcalls */
-char *alloca ();
-#   endif
-#  endif
-# endif
-#elif defined(__GNUC__) && defined(__STRICT_ANSI__)
-#define alloca __builtin_alloca
-#endif
-
-#include "popt.h"
+#include "system.h"
+#include "poptint.h"
 
 #define POPT_ARGV_ARRAY_GROW_DELTA 5
 
-int poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
-    char * buf, * bufStart, * dst;
+int poptDupArgv(int argc, const char **argv,
+		int * argcPtr, const char *** argvPtr)
+{
+    size_t nb = (argc + 1) * sizeof(*argv);
+    const char ** argv2;
+    char * dst;
+    int i;
+
+    for (i = 0; i < argc; i++) {
+	if (argv[i] == NULL)
+	    return POPT_ERROR_NOARG;
+	nb += strlen(argv[i]) + 1;
+    }
+	
+    dst = malloc(nb);
+    argv2 = (void *) dst;
+    dst += (argc + 1) * sizeof(*argv);
+
+    for (i = 0; i < argc; i++) {
+	argv2[i] = dst;
+	dst += strlen(strcpy(dst, argv[i])) + 1;
+    }
+    argv2[argc] = NULL;
+
+    *argvPtr = argv2;
+    *argcPtr = argc;
+    return 0;
+}
+
+int poptParseArgvString(const char * s, int * argcPtr, const char *** argvPtr)
+{
     const char * src;
     char quote = '\0';
     int argvAlloced = POPT_ARGV_ARRAY_GROW_DELTA;
-    char ** argv = malloc(sizeof(*argv) * argvAlloced);
-    char ** argv2;
+    const char ** argv = malloc(sizeof(*argv) * argvAlloced);
     int argc = 0;
-    int i, buflen;
+    int buflen = strlen(s) + 1;
+    char * buf = memset(alloca(buflen), 0, buflen);
 
-    buflen = strlen(s) + 1;
-    bufStart = buf = alloca(buflen);
-    memset(buf, '\0', buflen);
-
-    src = s;
     argv[argc] = buf;
 
-    while (*src) {
+    for (src = s; *src; src++) {
 	if (quote == *src) {
 	    quote = '\0';
 	} else if (quote) {
@@ -81,32 +81,38 @@ int poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
 		free(argv);
 		return POPT_ERROR_BADQUOTE;
 	    }
-	    /* fallthrough */
+	    /*@fallthrough@*/
 	  default:
 	    *buf++ = *src;
+	    break;
 	}
-
-	src++;
     }
 
     if (strlen(argv[argc])) {
 	argc++, buf++;
     }
 
-    dst = malloc(argc * sizeof(*argv) + (buf - bufStart));
-    argv2 = (void *) dst;
-    dst += argc * sizeof(*argv);
-    memcpy(argv2, argv, argc * sizeof(*argv));
-    memcpy(dst, bufStart, buf - bufStart);
+#if 0
+    {	char * dst = malloc((argc + 1) * sizeof(*argv) + (buf - argv[0]));
+	const char ** argv2 = (void *) dst;
+	int i;
 
-    for (i = 0; i < argc; i++) {
-	argv2[i] = dst + (argv[i] - bufStart);
+	dst += (argc + 1) * sizeof(*argv);
+	memcpy(argv2, argv, argc * sizeof(*argv));
+	argv2[argc] = NULL;
+	memcpy(dst, argv[0], buf - argv[0]);
+
+	for (i = 0; i < argc; i++)
+	    argv2[i] = dst + (argv[i] - argv[0]);
+
+	*argvPtr = argv2;
+	*argcPtr = argc;
     }
+#else
+    (void) poptDupArgv(argc, argv, argcPtr, argvPtr);
+#endif
 
     free(argv);
 
-    *argvPtr = argv2;
-    *argcPtr = argc;
-
     return 0;
 }
