@@ -231,12 +231,9 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		retval = ORBit_free_via_TypeCode(mem, &subtc, free_strings);
 		break;
 	default:
-	  {
-	    gulong alignval;
-	    retval = ((guchar *)mem);
-	    alignval = ORBit_gather_alloc_info(tc);
-	    retval = ALIGN_ADDRESS(mem, alignval) + alignval;
-	  }
+		/* NB. alignment != alloc size */
+		retval  = ALIGN_ADDRESS (mem, ORBit_find_alignment (tc)) +
+			ORBit_gather_alloc_info (tc);
 		break;
 	}
 
