@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: orbit-idl-driver.c,v 1.11 1999/07/19 18:04:56 sopwith Exp $
+    $Id: orbit-idl-driver.c,v 1.12 2000/02/16 18:59:46 sopwith Exp $
 
 ***************************************************************************/
 
@@ -53,6 +53,8 @@ orbit_idl_to_backend(const char *filename, OIDL_Run_Info *rinfo)
 			       &tree, &namespace,
 			       IDLF_TYPECODES|IDLF_CODEFRAGS,
 			       IDL_WARNINGMAX);
+  if(rinfo->debug_level > 1)
+    orbit_idl_print_node(tree, 0);
 
   if(IDL_SUCCESS != errcode) {
     if(errcode == -1)
